@@ -3,11 +3,10 @@ import os, ast, json, requests
 import datetime
 from dateutil.relativedelta import relativedelta
 from xero import Xero
-from sdc_dp_helpers.api_utilities.file_managers import load_file
+
 from sdc_dp_helpers.api_utilities.retry_managers import request_handler
 from sdc_dp_helpers.xero import auth_handler as pixie
 from sdc_dp_helpers.xero.config_managers import get_config
-from sdc_dp_helpers.xero.writers import CustomS3JsonWriter
 
 def date_filter_helper(from_date: str, to_date: str, filter_field: str = None) -> str:
     """
@@ -55,76 +54,6 @@ class CustomXeroReader:
             local_token_path= self.creds_path
         )
 
-    def fetch_report(self, request: dict) -> str:
-        """
-        This method accepts one dictionary Parameter
-            with the following compulsory keys:
-                report_name: the report name as per Xero API endpoint
-            and these optional keys:
-                from_date: the start_date of the report
-                to_date: the end date of the report
-        and returns the report for those parameters using the requests module to access the API directly
-        """
-        # unpack request
-        report_name = request["report_name"]
-        from_date = request.get( "from_date", request.get("date", None) )
-        to_date = request.get( "to_date", datetime.date.today().strftime('%Y-%m-%d') )
-        # TODO: loop through the individual months here, we don't really want the 
-        # reports mashed up into one object across many months. 
-        # For now we will raise an exception when from and to dates are not in the same month
-        if from_date[:7] != to_date[:7]:
-            raise ValueError("When pulling reports, make sure that the from_date and to_date fall within the same month. Iterating over multiple months is not developed for yet.")
-
-        tracking_category = request["tracking_category"]
-        if "filter_items" not in request.keys():
-            filter_items = (
-                request.get("filter_items", {})
-            )
-        xero_obj = request["xero_obj"]
-        auth_token = request["auth_token"]
-
-        my_headers = {
-            "Authorization": "Bearer " + auth_token.token["access_token"], # self.xero_client.token["access_token"],
-            "Xero-Tenant-Id": request['tenant_id'],
-            "Accept": "application/json",
-        }
-        my_params = {
-            "fromDate": from_date,
-            "toDate": to_date,
-        }
-        if tracking_category:
-            my_params.update({ "trackingCategoryID": tracking_category["TrackingCategoryID"] } )
-
-        my_params.update(filter_items)
-        response = requests.get(
-            "https://api.xero.com/api.xro/2.0/Reports/" + report_name,
-            params=my_params,
-            headers=my_headers,
-        )
-
-        
-        report_response = {
-            "tenantId": auth_token.tenant_id,
-            "trackingCategoryId": tracking_category["TrackingCategoryID"],
-            "report": None,
-            "from_date": from_date,
-            "to_date": to_date,
-        }
-        # there is no report, nothing to unpack
-        if response.status_code==400:
-            return None
-        
-        response = response.text
-        if not response:
-            return None
-
-        print(response)
-        response = response.replace("\r", "").replace("\n", "").strip("'<>() ")
-        report = json.loads(response)
-        
-        report_response["report"] = report
-        return json.dumps(report_response)
-
     def fetch_reports(self) -> dict:
         """
         Loops through reports in the config to pull each of them
@@ -140,45 +69,46 @@ class CustomXeroReader:
             ]:
                 raise ValueError(report_name + " is not supported or does not exist.")
 
-            self.auth_token = pixie.get_auth_token(self.config["client_id"], self.config["creds_path"])
-            for tenant_id in self.config["tenant_ids"]:
-                self.auth_token.tenant_id = tenant_id
-                xero_obj = Xero( self.auth_token )
-                trackingcategories = (
-                    i for i in xero_obj.trackingcategories.all() if i != None
-                )
+            self.auth_token = pixie.get_auth_token(self.client_id, self.creds_path)
 
-                for tracking_category in trackingcategories:
-                    request_params = {
-                        "report_name": report_name,
-                        "tenant_id": tenant_id,
-                        "tracking_category": tracking_category,
-                        "xero_obj": xero_obj,
-                        "auth_token": self.auth_token,
-                        "from_date": self.config.get("from_date"),
-                        "to_date": self.config.get("to_date")
-                    }
+            self.auth_token.tenant_id = tenant_id = self.config.get("tenant_id")
+            
+            xero_obj = Xero( self.auth_token )
+            trackingcategories = (
+                i for i in xero_obj.trackingcategories.all() if i != None
+            )
 
-                    if report_name in ["BalanceSheet", "ProfitAndLoss"]:
-                        result = self.fetch_report( request_params )
+            for tracking_category in trackingcategories:
+                request_params = {
+                    "report_name": report_name,
+                    "tenant_id": tenant_id,
+                    "tracking_category": tracking_category,
+                    "xero_obj": xero_obj,
+                    "auth_token": self.auth_token,
+                    "from_date": self.config.get("from_date"),
+                    "to_date": self.config.get("to_date")
+                }
+
+                if report_name in ["BalanceSheet", "ProfitAndLoss"]:
+                    result = self.fetch_report( request_params )
+                    if result and result != None:
+                        data_set[ (report_name + "_" + tracking_category["TrackingCategoryID"]) ] = result
+
+                elif report_name in ["AgedPayablesByContact", "AgedReceivablesByContact"]:
+
+                    for contact in xero_obj.contacts.filter(
+                        raw="AccountNumber!=null",
+                        AccountNumber__startswith="999999"
+                    ):
+                        print(contact["ContactID"])
+                        request_params.update({ "contactId": contact["ContactID"] })
+                        # print(type(report_name), type(tracking_category["TrackingCategoryID"]), type(contact_id))
+
+                        result = self.fetch_report(request_params)
                         if result and result != None:
-                            data_set[ (report_name + "_" + tracking_category["TrackingCategoryID"]) ] = result
-
-                    elif report_name in ["AgedPayablesByContact", "AgedReceivablesByContact"]:
-
-                        for contact in xero_obj.contacts.filter(
-                            raw="AccountNumber!=null",
-                            AccountNumber__startswith="999999"
-                        ):
-                            print(contact["ContactID"])
-                            request_params.update({ "contactId": contact["ContactID"] })
-                            # print(type(report_name), type(tracking_category["TrackingCategoryID"]), type(contact_id))
-
-                            result = self.fetch_report(request_params)
-                            if result and result != None:
-                                data_set[ (report_name + "_" + tracking_category["TrackingCategoryID"] + "_" + contact["ContactID"] ) ] = result
-                    else:
-                        raise ValueError(f"We don't currently have a process to process a report named '{report_name}'. Is it spelt properly in case and space?")
+                            data_set[ (report_name + "_" + tracking_category["TrackingCategoryID"] + "_" + contact["ContactID"] ) ] = result
+                else:
+                    raise ValueError(f"We don't currently have a process to process a report named '{report_name}'. Is it spelt properly in case and space?")
 
         return data_set
 
@@ -197,12 +127,15 @@ class CustomXeroReader:
         """
         # unpack request
         report_name = request["report_name"]
-        from_date = request.get( "from_date", request.get("date", None) )
-        to_date = request.get( "to_date", datetime.date.today().strftime('%Y-%m-%d') )
+
+        today = datetime.date.today()
+        three_months_back = ( today - relativedelta( months=3 ) ).strftime('%Y-%m-01')
+        today = today.strftime('%Y-%m-%d')
+
+        self.from_date = from_date = request.get( "from_date", request.get("date", three_months_back) )
+        self.to_date = to_date = request.get( "to_date", today )
         tracking_category = request["tracking_category"]
-        filter_items = (
-            None if "filter_items" not in request.keys() else request["filter_items"]
-        )
+        
         self.auth_token = pixie.get_auth_token(
             client_id=self.client_id,
             local_token_path=self.creds_path
@@ -221,7 +154,9 @@ class CustomXeroReader:
         if tracking_category:
             my_params.update({ "trackingCategoryID": tracking_category["TrackingCategoryID"] } )
 
-        my_params.update(filter_items)
+        if "filter_items" in request.keys():
+            my_params.update( request["filter_items"] )
+        
         response = requests.get(
             "https://api.xero.com/api.xro/2.0/Reports/" + report_name,
             params=my_params,
@@ -323,7 +258,7 @@ class CustomXeroReader:
                 page += 1
         return data_set
 
-    def run_main(self):
+    def run_query(self):
         """
         As dictated by the config;
         This function fetches all modules and reports requested based on the config
